@@ -4,7 +4,8 @@ Define context in which a plug-in runs
 from __future__ import annotations
 
 from dataclasses import dataclass
-from typing import TYPE_CHECKING
+import multiprocessing
+from typing import TYPE_CHECKING, Any, Optional
 
 # Only import these classes during type-checking
 #
@@ -23,7 +24,7 @@ if TYPE_CHECKING:  # pragma: no cover
 
 
 @dataclass
-class Context:
+class Context:  # pylint: disable="too-many-instance-attributes"
     """
     Define context in which a plug-in runs
     """
@@ -34,3 +35,5 @@ class Context:
     max_processes: int
     max_attempts: int = 3
     retry_wait_seconds: float = 5
+    logfile_lock: Optional[Any] = multiprocessing.Manager().RLock()
+    logfile_location: str = "hoppr.log"
