@@ -30,9 +30,12 @@ class CollectMavenPlugin(CollectorPlugin):
 
     def __init__(self, context: Context, config: Optional[Dict] = None) -> None:
         super().__init__(context=context, config=config)
+        self.extra_opts = []
         if self.config is not None:
             if "maven_command" in self.config:
                 self.required_commands = [self.config["maven_command"]]
+            if "maven_opts" in self.config:
+                self.extra_opts = self.config["maven_opts"]
 
     @hoppr_rerunner
     def collect(self, comp: Any, repo_url: str, creds: Optional[CredObject] = None):
@@ -83,6 +86,8 @@ class CollectMavenPlugin(CollectorPlugin):
                     [f"-Drepo.login={creds.username}", f"-Drepo.pwd={creds.password}"]
                 )
 
+            command.extend(self.extra_opts)
+
             result = self.run_command(command, password_list)
             if result.returncode != 0:
                 msg = f"Failed to download maven artifact {purl.namespace}:{purl.name}:{purl.version} type={extension}"
@@ -108,6 +113,8 @@ class CollectMavenPlugin(CollectorPlugin):
                         ]
                     )
 
+                command.extend(self.extra_opts)
+
                 result = self.run_command(command, password_list)
                 if result.returncode != 0:
                     msg = f"Failed to download pom for maven artifact {purl.namespace}:{purl.name}:{purl.version}"
